% This routine gives the integration constants A and B pertaining to the 
% solution of the Poisson Boltzmann for a cylidrical polyelectrolyte without 
% salt (counterions only) in the cell model. The theory is covered in the 
% lecture notes in section 3.3.2. 

% The initial guess for Re[B] is in the range 0.4 - 1, try different values 
% to satisfy the normalization criterium. 

%-----------------------------------------------------------------------------------------------------------

global lambda const_A const_B R a rho_R kappa_sqr

c          =    input('polyion concentration in monomol/l   : ');
bare_d     =    input('bare polyion diameter in nm          : ');
guess_B    =    input('initial guess re(B)                  : ');

% Constants
l_B        =    0.714;                                  % Bjerrum length in nm (water)
A          =    0.171;                                  % Distance between monomers in nm (B-form DNA)
N_A        =    6.022045e-1;                            % Avogadro number (modified magnitude, due to nm scale)

% System parameters 
a          =    bare_d / 2;                             % Polymer radius
R          =    sqrt(1 / (pi * A * c * N_A))            % Cell radius in nm (see beginning of section 3.3.2)
lambda     =    l_B / A;                                % Charge density parameter (eq. 3.11)

%-----------------------------------------------------------------------------------------------------------

% Determination of integration constant B (eq. 3.46)
% equation_B returns ((RHS of eqn. 3.46) - lambda) as a function of B
% fzero numerically solves ((RHS of eqn. 3.46) - lambda) = 0
const_B    =    sqrt(-1) * fzero('equation_B', guess_B)
   

% Determination of integration constant A (eq. 3.45)
const_A    =    exp(-atanh(const_B) / const_B) / R;

% Osmotic coefficient (eq. 3.50)
Phi        =    (1 - const_B^2) / (2 * lambda);         

% Counterion concentration at the cell boundary in nm^-3
rho_R      =    Phi / (pi * R^2 * A)               

% Screening length (see below eq. 3.43) 
kappa_sqr  =    4 * pi * l_B * rho_R; 

%-----------------------------------------------------------------------------------------------------------

% The integral over the radial counterion density profile times A
% the projected distance between the charges should be unity.
% If this is not unity, try another value for re(B).                             
% PB_profile returns the counterion density profile rho_c (r).
% quadl('f', a, b) performs a numerical interation of f from a to b.
  
A * quadl('PB_profile', a, R)

%-----------------------------------------------------------------------------------------------------------

% Plot the potential phi
% PB_potential returns the potential phi(r) (eq. 3.44)

xlabel('r (nm)')
ylabel('reduced potential')

plot([a : 0.1 : R], real(-PB_potential([a : 0.1 : R])) )  


